cheesecake.model.Documentable

Package cheesecake :: Module model :: Class Documentable |
[hide private]
[frames] | no frames]

## Class Documentable
source code

    object --+
             |
            Documentable

Known Subclasses:
  Class, Function, Module, Package

Instance Methods | [hide private]
| __init__(self, system, prefix, name, docstring, parent=None) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
| setup(self)
| fullName(self)
| shortdocstring(self)
| __repr__(self) repr(x)
| name2fullname(self, name)
| resolveDottedName(self, dottedname, verbose=False)
| dottedNameToFullName(self, dottedname)
| __getstate__(self)
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`

Class Variables | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, system, prefix, name, docstring, parent=None) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### setup(self) | source code

### fullName(self) | source code

### shortdocstring(self) | source code

### __repr__(self) (Representation operator) | source code
repr(x) Overrides: object.__repr__ (inherited documentation)

### name2fullname(self, name) | source code

### resolveDottedName(self, dottedname, verbose=False) | source code

### dottedNameToFullName(self, dottedname) | source code

### __getstate__(self) | source code